@@ -1,9 +1,8 @@
-import os, sys, json, random, platform, eventlet, time, re, pyproxify
+import os, sys, json, random, platform, time, re, pyproxify
 #from scapy.all import *
 import itertools
 import threading
 from ua_headers import ua
-eventlet.monkey_patch()
 
 r = "\033[31m"
 g = "\033[32m"
@@ -26,7 +25,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.8"
+version = "1.2.9"
 referer_list = ["https://www.google.com/", "https://www.youtube.com/", "https://www.twitter.com/", "https://www.discord.com/", "https://www.tiktok.com/", "https://www.instagram.com/", "https://check-host.net/", "https://github.com", "https://gitlab.com", "https://he1zen.rf.gd"]
 
 major = str(sys.version_info.major)
@@ -35,7 +34,7 @@ path = str(sys.exec_prefix+"/lib/python"+major+"."+minor+"/site-packages/iphack/
 
 global log
 global anon
-anon = "tor"
+anon = "web"
 log = False
 
 class ip:
@@ -430,7 +429,6 @@ class inquiry:
                              print("[100%] Success")
                          return get
             except:
-                 timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
                      ip = p["socksip"]
@@ -504,11 +502,10 @@ class inquiry:
                         if log:
                             print("[90%] Requests post URL")
                         try:
-                            with eventlet.Timeout(25) as time:
-                                post = sess.post(*args, **kwargs)
-                                if log:
-                                    print("[100%] Success")
-                                return post
+                            post = sess.post(*args, **kwargs)
+                            if log:
+                                print("[100%] Success")
+                            return post
                         except:
                              return '\033[91m403 Website refused to connect\x1B[37m'
         elif anon == "vpn":
@@ -529,21 +526,19 @@ class inquiry:
                      print("[70%] Proxy "+ip+":"+port)
                  proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
                  import requests
-                 with eventlet.Timeout(10) as timeo:
+                 if log:
+                     print("[80%] Getting fake IP address")
+                 with requests.Session() as s:
+                     s.proxies.update(proxies)
+                     args = " ".join([str(m) for m in args])
+                     url = args.replace("https", "http")
                      if log:
-                         print("[80%] Getting fake IP address")
-                     with requests.Session() as s:
-                         s.proxies.update(proxies)
-                         args = " ".join([str(m) for m in args])
-                         url = args.replace("https", "http")
-                         if log:
-                             print("[90%] Requests post URL")
-                         post = s.post(url, **kwargs, headers={"User-Agent": ua.windows()})
-                         if log:
-                             print("[100%] Success")
-                         return post
+                         print("[90%] Requests post URL")
+                     post = s.post(url, **kwargs, headers={"User-Agent": ua.windows()})
+                     if log:
+                         print("[100%] Success")
+                     return post
             except:
-                 timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
                      ip = p["socksip"]
@@ -553,13 +548,12 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
-                     with eventlet.Timeout(15) as timeoo:
-                         with requests.Session() as ss:
-                             ss.proxies.update(proxies)
-                             post = ss.post(args, **kwargs, headers={"User-Agent": ua.windows()})
-                             if log:
-                                 print("[100%] Success")
-                             return post
+                     with requests.Session() as ss:
+                         ss.proxies.update(proxies)
+                         post = ss.post(args, **kwargs, headers={"User-Agent": ua.windows()})
+                         if log:
+                             print("[100%] Success")
+                         return post
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def put(*args, **kwargs):
@@ -593,11 +587,10 @@ class inquiry:
                         if log:
                             print("[90%] Requests put URL")
                         try:
-                            with eventlet.Timeout(25) as time:
-                                put = sess.put(*args, **kwargs)
-                                if log:
-                                    print("[100%] Success")
-                                return put
+                            put = sess.put(*args, **kwargs)
+                            if log:
+                                print("[100%] Success")
+                            return put
                         except:
                             return '\033[91m403 Website refused to connect\x1B[37m'
         elif anon == "vpn":
@@ -618,21 +611,19 @@ class inquiry:
                      print("[70%] Proxy "+ip+":"+port)
                  proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
                  import requests
-                 with eventlet.Timeout(10) as timeo:
+                 if log:
+                     print("[80%] Getting fake IP address")
+                 with requests.Session() as s:
+                     s.proxies.update(proxies)
+                     args = " ".join([str(m) for m in args])
+                     url = args.replace("https", "http")
                      if log:
-                         print("[80%] Getting fake IP address")
-                     with requests.Session() as s:
-                         s.proxies.update(proxies)
-                         args = " ".join([str(m) for m in args])
-                         url = args.replace("https", "http")
-                         if log:
-                             print("[90%] Requests put URL")
-                         put = s.put(url, **kwargs, headers={"User-Agent": ua.windows()})
-                         if log:
-                             print("[100%] Success")
-                         return put
+                         print("[90%] Requests put URL")
+                     put = s.put(url, **kwargs, headers={"User-Agent": ua.windows()})
+                     if log:
+                         print("[100%] Success")
+                     return put
             except:
-                 timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
                      ip = p["socksip"]
@@ -642,13 +633,12 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
-                     with eventlet.Timeout(15) as timeoo:
-                         with requests.Session() as ss:
-                             ss.proxies.update(proxies)
-                             put = ss.put(args, **kwargs, headers={"User-Agent": ua.windows()})
-                             if log:
-                                 print("[100%] Success")
-                             return put
+                     with requests.Session() as ss:
+                         ss.proxies.update(proxies)
+                         put = ss.put(args, **kwargs, headers={"User-Agent": ua.windows()})
+                         if log:
+                             print("[100%] Success")
+                         return put
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def delete(*args, **kwargs):
@@ -682,11 +672,10 @@ class inquiry:
                         if log:
                             print("[90%] Requests delete URL")
                         try:
-                            with eventlet.Timeout(25) as time:
-                                delete = sess.delete(*args, **kwargs)
-                                if log:
-                                    print("[100%] Success")
-                                return delete
+                            delete = sess.delete(*args, **kwargs)
+                            if log:
+                                print("[100%] Success")
+                            return delete
                         except:
                             return '\033[91m403 Website refused to connect\x1B[37m'
         elif anon == "vpn":
@@ -707,21 +696,19 @@ class inquiry:
                      print("[70%] Proxy "+ip+":"+port)
                  proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
                  import requests
-                 with eventlet.Timeout(10) as timeo:
+                 if log:
+                     print("[80%] Getting fake IP address")
+                 with requests.Session() as s:
+                     s.proxies.update(proxies)
+                     args = " ".join([str(m) for m in args])
+                     url = args.replace("https", "http")
                      if log:
-                         print("[80%] Getting fake IP address")
-                     with requests.Session() as s:
-                         s.proxies.update(proxies)
-                         args = " ".join([str(m) for m in args])
-                         url = args.replace("https", "http")
-                         if log:
-                             print("[90%] Requests delete URL")
-                         delete = s.delete(url, **kwargs, headers={"User-Agent": ua.windows()})
-                         if log:
-                             print("[100%] Success")
-                         return delete
+                         print("[90%] Requests delete URL")
+                     delete = s.delete(url, **kwargs, headers={"User-Agent": ua.windows()})
+                     if log:
+                         print("[100%] Success")
+                     return delete
             except:
-                 timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
                      ip = p["socksip"]
@@ -731,13 +718,12 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
-                     with eventlet.Timeout(15) as timeoo:
-                         with requests.Session() as ss:
-                             ss.proxies.update(proxies)
-                             delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
-                             if log:
-                                 print("[100%] Success")
-                             return delete
+                     with requests.Session() as ss:
+                         ss.proxies.update(proxies)
+                         delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
+                         if log:
+                             print("[100%] Success")
+                         return delete
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def head(*args, **kwargs):
@@ -771,11 +757,10 @@ class inquiry:
                         if log:
                             print("[90%] Requests head URL")
                         try:
-                            with eventlet.Timeout(25) as time:
-                                head = sess.head(*args, **kwargs)
-                                if log:
-                                    print("[100%] Success")
-                                return head
+                            head = sess.head(*args, **kwargs)
+                            if log:
+                                print("[100%] Success")
+                            return head
                         except:
                              return '\033[91m403 Website refused to connect\x1B[37m'
         elif anon == "vpn":
@@ -796,21 +781,19 @@ class inquiry:
                      print("[70%] Proxy "+ip+":"+port)
                  proxies = {"http":"http://"+proxy, "https":"http://"+proxy}
                  import requests
-                 with eventlet.Timeout(10) as timeo:
+                 if log:
+                     print("[80%] Getting fake IP address")
+                 with requests.Session() as s:
+                     s.proxies.update(proxies)
+                     args = " ".join([str(m) for m in args])
+                     url = args.replace("https", "http")
                      if log:
-                         print("[80%] Getting fake IP address")
-                     with requests.Session() as s:
-                         s.proxies.update(proxies)
-                         args = " ".join([str(m) for m in args])
-                         url = args.replace("https", "http")
-                         if log:
-                             print("[90%] Requests head URL")
-                         head = s.head(url, **kwargs, headers={"User-Agent": ua.windows()})
-                         if log:
-                             print("[100%] Success")
-                         return head
+                         print("[90%] Requests head URL")
+                     head = s.head(url, **kwargs, headers={"User-Agent": ua.windows()})
+                     if log:
+                         print("[100%] Success")
+                     return head
             except:
-                 timeo.cancel()
                  try:
                      p = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
                      ip = p["socksip"]
@@ -820,13 +803,12 @@ class inquiry:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
                      proxies = {"http":"socks5://he1zen:he1zen@"+proxy, "https":"socks5://he1zen:he1zen@"+proxy}
-                     with eventlet.Timeout(15) as timeoo:
-                         with requests.Session() as ss:
-                             ss.proxies.update(proxies)
-                             delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
-                             if log:
-                                 print("[100%] Success")
-                             return delete
+                     with requests.Session() as ss:
+                         ss.proxies.update(proxies)
+                         delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
+                         if log:
+                             print("[100%] Success")
+                         return delete
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def debug():
